@@ -9,8 +9,7 @@ from .authenticate import Authenticate
 
 
 class Runner(Authenticate):
-    def __init__(self, asset_host_key='host', asset_name='asset', action_name=None, context=None):
-        self.asset_host_key = asset_host_key
+    def __init__(self, asset_name='asset', action_name=None, context=None):
         # Swimlane
         if context:
             self.asset = context.asset
@@ -18,6 +17,7 @@ class Runner(Authenticate):
             self.endpoint = context.manifest['meta']['endpoint']
             self.method = context.manifest['meta']['method']
             self.security = context.manifest['meta']['security']
+            self.asset_url_key = self.asset_manifest['meta'].get('asset_url_key', 'url')
         # Turbine
         else:
             self.asset_manifest, self.action_manifest = self._load_schemas(action_name, asset_name)
@@ -25,6 +25,7 @@ class Runner(Authenticate):
             self.endpoint = self.action_manifest['meta']['endpoint']
             self.method = self.action_manifest['meta']['method']
             self.security = self.asset_manifest['meta']['security']
+            self.asset_url_key = self.asset_manifest['meta'].get('asset_url_key', 'url')
 
         # Build session
         self.session = Session()
@@ -40,7 +41,7 @@ class Runner(Authenticate):
 
     @staticmethod
     def _load_schemas(action_name, asset_name):
-        manifests = glob.glob('../**/*.yaml', recursive=True)
+        manifests = glob.glob('./**/*.yaml', recursive=True)
         asset_manifest = None
         action_manifest = None
         for manifest in manifests:
@@ -105,7 +106,7 @@ class Runner(Authenticate):
     def run(self):
         response = self.session.request(
             self.method,
-            urljoin(self.asset[self.asset_host_key], self.get_endpoint()),
+            urljoin(self.asset[self.asset_url_key], self.get_endpoint()),
             **self.get_kwargs()
         )
         resp = self.parse_response(response)
